# crt
Cloud Render Toolkit

[ ![Codeship Status for rojopolis/crt](https://app.codeship.com/projects/4494a230-62c2-0136-29ae-6e1d62f3513e/status?branch=master)](https://app.codeship.com/projects/296887)


[![codecov](https://codecov.io/gh/rojopolis/crt/branch/master/graph/badge.svg)](https://codecov.io/gh/rojopolis/crt/branch/master/graph/badge.svg)
